@@ -19,7 +19,8 @@
 #include "LogBook.hpp"
 #include "LogBookCommon.hpp"
 #include "LogBookConfigDialog.hpp"
-#include "LogBookDialog.hpp"
+#include "ObservationsDialog.hpp"
+#include "SessionsDialog.hpp"
 #include "TargetsDialog.hpp"
 
 #include "stdexcept"
@@ -34,6 +35,7 @@
 #include "StelObjectType.hpp"
 #include "StelProjector.hpp"
 #include "StelPainter.hpp"
+#include "StelStyle.hpp"
 #include "StelTranslator.hpp"
 
 #include <QAction>
@@ -101,6 +103,9 @@ LogBook::LogBook()
 
 LogBook::~LogBook()
 {
+	delete configDialog;
+	delete sessionsDialog;
+	delete targetsDialog;
 }
 
 /* ********************************************************************* */
@@ -114,6 +119,11 @@ bool LogBook::configureGui(bool)
 	return true;
 }
 
+void LogBook::draw(StelCore* core)
+{
+	StelPainter painter(core->getProjection2d());
+}
+
 double LogBook::getCallOrder(StelModuleActionName actionName) const
 {
 	if (actionName==StelModule::ActionDraw) {
@@ -122,24 +132,47 @@ double LogBook::getCallOrder(StelModuleActionName actionName) const
 	return 0;
 }
 
+const StelStyle LogBook::getModuleStyleSheet(const StelStyle& style)
+{
+	StelStyle pluginStyle(style);
+	if (style.confSectionName == "color") {
+		pluginStyle.qtStyleSheet.append(normalStyleSheet);
+	} else {
+		pluginStyle.qtStyleSheet.append(nightStyleSheet);
+	}
+	return pluginStyle;
+}
+
 void LogBook::init()
 {
 	qDebug() << "LogBook plugin - press Command-L to toggle Log Book view mode. Press ALT-L for configuration.";
 	initializeDatabase();
-	mainDialog = new LogBookDialog(tableModels);
+	//Load the module's custom style sheets
+	QFile styleSheetFile;
+	styleSheetFile.setFileName(":/logbook/normalStyle.css");
+	if(styleSheetFile.open(QFile::ReadOnly|QFile::Text)){
+		normalStyleSheet = styleSheetFile.readAll();
+	}
+	styleSheetFile.close();
+	styleSheetFile.setFileName(":/logbook/nightStyle.css");
+	if(styleSheetFile.open(QFile::ReadOnly|QFile::Text)){
+		nightStyleSheet = styleSheetFile.readAll();
+	}
+	styleSheetFile.close();
+
 	configDialog = new LogBookConfigDialog(tableModels);
+	sessionsDialog = new SessionsDialog(tableModels);
 	targetsDialog = new TargetsDialog(tableModels);
 	flagShowLogBook = false;
 	initializeActions();
 }
 
-void LogBook::draw(StelCore* core)
-{
-	StelPainter painter(core->getProjection2d());
-}
-
-void LogBook::setStelStyle(const QString& )
+void LogBook::setStelStyle(const QString&)
 {
+	qDebug() << "====> Here.";
+	configDialog->updateStyle();
+	sessionsDialog->updateStyle();
+	targetsDialog->updateStyle();
 }
 
 /* ********************************************************************* */
@@ -150,7 +183,7 @@ void LogBook::setStelStyle(const QString& )
 /* ********************************************************************* */
 void LogBook::enableLogBook(bool b)
 {
-	mainDialog->setVisible(b);
+	sessionsDialog->setVisible(b);
 	// Toggle the plugin on & off.  To toggle on, we want to ensure there is a selected object.
 	if (!StelApp::getInstance().getStelObjectMgr().getWasSelected()) {
 		qDebug() << "====> Nothing selected.";
@@ -250,7 +283,7 @@ bool LogBook::initializeDatabase()
 
 		tableModels[OBSERVATIONS] = new QSqlTableModel(this, db);
 		tableModels[OBSERVATIONS]->setTable(OBSERVATIONS);
-		tableModels[OBSERVATIONS]->setObjectName("Observers Table Model");
+		tableModels[OBSERVATIONS]->setObjectName("Observations Table Model");
 		tableModels[OBSERVATIONS]->setEditStrategy(QSqlTableModel::OnFieldChange);
 		tableModels[OBSERVATIONS]->select();
 
