@@ -1,17 +1,17 @@
 /*
  * Stellarium
  * Copyright (C) 2009 Matthew Gates
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
@@ -21,19 +21,12 @@
 #include "StelObject.hpp"
 #include "StelPainter.hpp"
 #include "StelApp.hpp"
-#include "StelNavigator.hpp"
 #include "StelLocation.hpp"
 #include "StelCore.hpp"
 #include "StelTexture.hpp"
 #include "VecMath.hpp"
 #include "StelUtils.hpp"
 
-
-#include "gsatellite/gSatTEME.hpp"
-#include "gsatellite/gObserver.hpp"
-#include "gsatellite/gTime.hpp"
-#include "gsatellite/gVector.hpp"
-
 #include <QTextStream>
 #include <QRegExp>
 #include <QDebug>
@@ -42,6 +35,8 @@
 #include <QSettings>
 #include <QByteArray>
 
+#include "gsatellite/gTime.hpp"
+
 #include <cmath>
 
 // static data members - will be initialised in the Satallites class (the StelObjectMgr)
@@ -57,12 +52,12 @@ bool Satellite::orbitLinesFlag = true;
 
 
 Satellite::Satellite(const QVariantMap& map)
-	: initialized(false), visible(true), hintColor(0.0,0.0,0.0), lastUpdated(), pSatellite(NULL)
+		: initialized(false), visible(true), hintColor(0.0,0.0,0.0), lastUpdated(), pSatWrapper(NULL)
 {
 	// return initialized if the mandatory fields are not present
 	if (!map.contains("designation") || !map.contains("tle1") || !map.contains("tle2"))
 		return;
-	
+
 	font.setPixelSize(16);
 
 	designation  = map.value("designation").toString();
@@ -108,7 +103,7 @@ Satellite::Satellite(const QVariantMap& map)
 
 	if (map.contains("comms"))
 	{
-		foreach(QVariant comm, map.value("comms").toList())
+                foreach(const QVariant &comm, map.value("comms").toList())
 		{
 			QVariantMap commMap = comm.toMap();
 			commLink c;
@@ -121,7 +116,7 @@ Satellite::Satellite(const QVariantMap& map)
 
 	if (map.contains("groups"))
 	{
-		foreach(QVariant group, map.value("groups").toList())
+                foreach(const QVariant &group, map.value("groups").toList())
 		{
 			if (!groupIDs.contains(group.toString()))
 				groupIDs << group.toString();
@@ -134,15 +129,13 @@ Satellite::Satellite(const QVariantMap& map)
 	{
 		lastUpdated = map.value("lastUpdated").toDateTime();
 	}
-
-	setObserverLocation();
 	initialized = true;
 }
 
 Satellite::~Satellite()
 {
-	if(pSatellite != NULL)
-		delete pSatellite;
+	if (pSatWrapper != NULL)
+		delete pSatWrapper;
 }
 
 double Satellite::roundToDp(float n, int dp)
@@ -169,7 +162,7 @@ QVariantMap Satellite::getMap(void)
 	map["hintColor"] = col;
 	map["orbitColor"] = orbitCol;
 	QVariantList commList;
-	foreach(commLink c, comms)
+        foreach(const commLink &c, comms)
 	{
 		QVariantMap commMap;
 		commMap["frequency"] = c.frequency;
@@ -178,8 +171,8 @@ QVariantMap Satellite::getMap(void)
 		commList << commMap;
 	}
 	map["comms"] = commList;
-		QVariantList groupList;
-	foreach(QString g, groupIDs)
+	QVariantList groupList;
+        foreach(const QString &g, groupIDs)
 	{
 		groupList << g;
 	}
@@ -193,7 +186,7 @@ QVariantMap Satellite::getMap(void)
 	return map;
 }
 
-float Satellite::getSelectPriority(const StelNavigator*) const
+float Satellite::getSelectPriority(const StelCore*) const
 {
 	return -10.;
 }
@@ -203,7 +196,7 @@ QString Satellite::getInfoString(const StelCore *core, const InfoStringGroup& fl
 	QString str;
 	QTextStream oss(&str);
 
-	if (flags&Name) 
+	if (flags&Name)
 	{
 		oss << "<h2>" << designation << "</h2><br>";
 		if (description!="")
@@ -219,24 +212,43 @@ QString Satellite::getInfoString(const StelCore *core, const InfoStringGroup& fl
 		oss << QString("Range (km): <b>%1</b>").arg(range, 5, 'f', 2) << "<br>";
 		oss << QString("Range rate (km/s): <b>%1</b>").arg(rangeRate, 5, 'f', 3) << "<br>";
 		oss << QString("Altitude (km): <b>%1</b>").arg(height, 5, 'f', 2) << "<br>";
-		oss << QString("SubPoint Lat/Long(Deg): <b>%1</b>").arg(LatLong[0], 5, 'f', 2) << "/";
-		oss << QString("<b>%1</b>").arg(LatLong[1], 5, 'f', 3);
+                oss << QString("SubPoint Lat/Long(Deg): <b>%1</b>").arg(latLongSubPointPosition[0], 5, 'f', 2) << "/";
+                oss << QString("<b>%1</b>").arg(latLongSubPointPosition[1], 5, 'f', 3);
 		oss << "</p>";
 
 		oss << "TEME Coordinates(km):  ";
-		oss << QString("<b>X:</b> %1 ").arg(Position[0], 5, 'f', 2);
-		oss << QString("<b>Y:</b> %1 ").arg(Position[1], 5, 'f', 2);
-		oss << QString("<b>Z:</b> %1 ").arg(Position[2], 5, 'f', 2) << "<br>";
+                oss << QString("<b>X:</b> %1 ").arg(position[0], 5, 'f', 2);
+                oss << QString("<b>Y:</b> %1 ").arg(position[1], 5, 'f', 2);
+                oss << QString("<b>Z:</b> %1 ").arg(position[2], 5, 'f', 2) << "<br>";
 		oss << "TEME Vel(km/s):  ";
-		oss << QString("<b>X:</b> %1 ").arg(Vel[0], 5, 'f', 2);
-		oss << QString("<b>Y:</b> %1 ").arg(Vel[1], 5, 'f', 2);
-		oss << QString("<b>Z:</b> %1 ").arg(Vel[2], 5, 'f', 2) << "<br>";
+                oss << QString("<b>X:</b> %1 ").arg(velocity[0], 5, 'f', 2);
+                oss << QString("<b>Y:</b> %1 ").arg(velocity[1], 5, 'f', 2);
+                oss << QString("<b>Z:</b> %1 ").arg(velocity[2], 5, 'f', 2) << "<br>";
 
+		oss << "Visibility:  ";
+                switch (visibility)
+		{
+		case RADAR_SUN:
+			oss << "Sat&Observer in Sunlit" << "<br>";
+			break;
+		case VISIBLE:
+			oss << "Visible" << "<br>";
+			break;
+		case RADAR_NIGHT:
+			oss << "Sat. Eclipsed" << "<br>";
+			break;
+		case NOT_VISIBLE:
+			oss << "Sat. Not Visible" << "<br>";
+			break;
+		default:
+			break;
+
+		}
 	}
 
 	if (flags&Extra2 && comms.size() > 0)
 	{
-		foreach (commLink c, comms)
+                foreach(const commLink &c, comms)
 		{
 			double dop = getDoppler(c.frequency);
 			double ddop = dop;
@@ -254,37 +266,21 @@ QString Satellite::getInfoString(const StelCore *core, const InfoStringGroup& fl
 			if (!c.description.isEmpty() && c.description != "") oss << "  " << c.description;
 			if ((!c.modulation.isEmpty() && c.modulation != "") || (!c.description.isEmpty() && c.description != "")) oss << "<br>";
 			oss << QString("%1 MHz (%2%3 kHz)</p>").arg(c.frequency, 8, 'f', 5)
-			                                       .arg(sign)
-			                                       .arg(ddop, 6, 'f', 3);
-		}		
+			.arg(sign)
+			.arg(ddop, 6, 'f', 3);
+		}
 	}
 
 	postProcessInfoString(str, flags);
 	return str;
 }
 
-void Satellite::setObserverLocation(StelLocation* loc)
+Vec3f Satellite::getInfoColor(void) const
 {
-	StelLocation l;
-	if (loc==NULL)
-	{
-		l = StelApp::getInstance().getCore()->getNavigator()->getCurrentLocation();
-	}
-	else
-	{
-		l = *loc;
-	}
-
-
-	observer.setPosition( l.latitude, l.longitude, l.altitude / 1000.0);
-
-}
-
-Vec3f Satellite::getInfoColor(void) const {
 	return StelApp::getInstance().getVisionModeNight() ? Vec3f(0.6, 0.0, 0.0) : hintColor;
 }
 
-float Satellite::getVMagnitude(const StelNavigator*) const
+float Satellite::getVMagnitude(const StelCore*) const
 {
 	return 5.0;
 }
@@ -296,10 +292,10 @@ double Satellite::getAngularSize(const StelCore*) const
 
 void Satellite::setNewTleElements(const QString& tle1, const QString& tle2)
 {
-	if (pSatellite)
+	if (pSatWrapper)
 	{
-		gSatTEME *old = pSatellite;
-		pSatellite = NULL;
+		gSatWrapper *old = pSatWrapper;
+		pSatWrapper = NULL;
 		delete old;
 	}
 
@@ -308,44 +304,29 @@ void Satellite::setNewTleElements(const QString& tle1, const QString& tle2)
 	tleElements.second.clear();
 	tleElements.second.append(tle2);
 
-	// The TLE library actually modifies the TLE strings, which is annoying (because
-	// when we get updates, we want to check if there has been a change by using ==
-	// with the original.  Thus we make a copy to send to the TLE library.
-	QByteArray t1(tleElements.first), t2(tleElements.second);
-
-	// Also, the TLE library expects no more than 130 characters length input.  We
-	// shouldn't have sane input with a TLE longer than about 80, but just in case
-	// we have a mal-formed input, we will truncate here to be safe
-	t1.truncate(130);
-	t2.truncate(130);
-
-	pSatellite = new gSatTEME(designation.toAscii().data(),
-				  t1.data(),
-				  t2.data());
+	pSatWrapper = new gSatWrapper(designation, tle1, tle2);
+	orbitPoints.clear();
 }
 
 void Satellite::update(double)
 {
-	double jul_utc = StelApp::getInstance().getCore()->getNavigator()->getJDay();
-
-	epochTime = jul_utc;
-
-	if (pSatellite)
+	if (pSatWrapper)
 	{
-		pSatellite->setEpoch( epochTime);
-		Position = pSatellite->getPos();
-		Vel      = pSatellite->getVel();
-		LatLong  = pSatellite->getSubPoint( epochTime);
-		azElPos  = observer.calculateLook( *pSatellite, epochTime);
+		epochTime = StelApp::getInstance().getCore()->getJDay();
 
-		azimuth   = azElPos[ AZIMUTH]/KDEG2RAD;
-		elevation = azElPos[ ELEVATION]/KDEG2RAD;
-		range     = azElPos[ RANGE];
-		rangeRate = azElPos[ RANGERATE];
-		height    = LatLong[2];
+		pSatWrapper->setEpoch(epochTime);
+                position                 = pSatWrapper->getTEMEPos();
+                velocity                 = pSatWrapper->getTEMEVel();
+                latLongSubPointPosition  = pSatWrapper->getSubPoint();
+                height                   = latLongSubPointPosition[2];
+                elAzPosition             = pSatWrapper->getAltAz();
+                elAzPosition.normalize();
+
+		pSatWrapper->getSlantRange(range, rangeRate);
+                visibility = pSatWrapper->getVisibilityPredict();
 
 		// Compute orbit points to draw orbit line.
-		if(orbitVisible) computeOrbitPoints();
+		if (orbitVisible) computeOrbitPoints();
 	}
 }
 
@@ -353,7 +334,7 @@ double Satellite::getDoppler(double freq) const
 {
 	double result;
 	double f = freq * 1000000;
-	result = -f*((rangeRate*1000.0)/SPEED_OF_LIGHT);
+        result   = -f*((rangeRate*1000.0)/SPEED_OF_LIGHT);
 	return result/1000000;
 }
 
@@ -364,17 +345,14 @@ void Satellite::recalculateOrbitLines(void)
 
 void Satellite::draw(const StelCore* core, StelPainter& painter, float)
 {
-	float a = (azimuth-90)*M_PI/180;
-	Vec3d pos(sin(a),cos(a), tan(elevation * M_PI / 180.));
-        XYZ = core->getNavigator()->altAzToJ2000(pos);
+		XYZ = core->altAzToJ2000(elAzPosition);
 	StelApp::getInstance().getVisionModeNight() ? glColor4f(0.6,0.0,0.0,1.0) : glColor4f(hintColor[0],hintColor[1],hintColor[2], Satellite::hintBrightness);
 
-
 	StelProjectorP prj = core->getProjection(StelCore::FrameJ2000);
+
 	Vec3d xy;
 	if (prj->project(XYZ,xy))
 	{
-
 		if (Satellite::showLabels)
 		{
 			painter.drawText(xy[0], xy[1], designation, 0, 10, 10, false);
@@ -382,54 +360,45 @@ void Satellite::draw(const StelCore* core, StelPainter& painter, float)
 		}
 		painter.drawSprite2dMode(xy[0], xy[1], 11);
 
-		if(orbitVisible && Satellite::orbitLinesFlag) drawOrbit(painter);
+		if (orbitVisible && Satellite::orbitLinesFlag) drawOrbit(painter);
 	}
 }
 
 
-void Satellite::drawOrbit(StelPainter& painter){
-
-	Vec3d pos,posPrev;
-
-	float a, azimth, elev;
+void Satellite::drawOrbit(StelPainter& painter)
+{
+        Vec3d position,previousPosition;
 
 	glDisable(GL_TEXTURE_2D);
 
-	QList<gVector>::iterator it= orbitPoints.begin();
+	QList<Vec3d>::iterator it= orbitPoints.begin();
 
 	//First point projection calculation
-	azimth = it->at( AZIMUTH);
-	elev   = it->at( ELEVATION);
-	a      = ( (azimth/KDEG2RAD)-90)*M_PI/180;
-	posPrev.set(sin(a),cos(a), tan( (elev/KDEG2RAD) * M_PI / 180.));
+        previousPosition.set(it->operator [](0), it->operator [](1), it->operator [](2));
 
 	it++;
 	StelVertexArray vertexArray;
 	vertexArray.primitiveType=StelVertexArray::Lines;
 
 	//Rest of points
-	for(int i=1; i<orbitPoints.size();i++)
+	for (int i=1; i<orbitPoints.size(); i++)
 	{
-		azimth = it->at( AZIMUTH);
-		elev   = it->at( ELEVATION);
-		a      = ( (azimth/KDEG2RAD)-90)*M_PI/180;
-		pos.set(sin(a),cos(a), tan( (elev/KDEG2RAD) * M_PI / 180.));
+                position.set(it->operator [](0), it->operator [](1), it->operator [](2));
 		it++;
-
-		pos.normalize();
-		posPrev.normalize();
+                position.normalize();
+                previousPosition.normalize();
 
 		// Draw end (fading) parts of orbit lines one segment at a time.
 		if (i<=orbitLineFadeSegments || orbitLineSegments-i < orbitLineFadeSegments)
 		{
 			painter.setColor((*orbitColor)[0], (*orbitColor)[1], (*orbitColor)[2], hintBrightness * calculateOrbitSegmentIntensity(i));
-			painter.drawGreatCircleArc(posPrev, pos, &viewportHalfspace);
+                        painter.drawGreatCircleArc(previousPosition, position, &viewportHalfspace);
 		}
-		else {
-			vertexArray.vertex << posPrev << pos;
+		else
+		{
+                        vertexArray.vertex << previousPosition << position;
 		}
-
-		posPrev = pos;
+                previousPosition = position;
 	}
 
 	// Draw center section of orbit in one go
@@ -444,8 +413,14 @@ void Satellite::drawOrbit(StelPainter& painter){
 float Satellite::calculateOrbitSegmentIntensity(int segNum)
 {
 	int endDist = (orbitLineSegments/2) - abs(segNum-1 - (orbitLineSegments/2) % orbitLineSegments);
-	if (endDist > orbitLineFadeSegments) { return 1.0; }
-	else { return (endDist  + 1) / (orbitLineFadeSegments + 1.0); }
+	if (endDist > orbitLineFadeSegments)
+	{
+		return 1.0;
+	}
+	else
+	{
+		return (endDist  + 1) / (orbitLineFadeSegments + 1.0);
+	}
 }
 
 void Satellite::setNightColors(bool night)
@@ -459,78 +434,80 @@ void Satellite::setNightColors(bool night)
 
 void Satellite::computeOrbitPoints()
 {
-
 	gTimeSpan computeInterval(0, 0, 0, orbitLineSegmentDuration);
 	gTimeSpan orbitSpan(0, 0, 0, orbitLineSegments*orbitLineSegmentDuration/2);
 	gTime	  epochTm;
-	gVector   azElVector;
-	int	  diffSlots;
+        gTime	  epoch(epochTime);
+	gTime	  lastEpochComp(lastEpochCompForOrbit);
+        Vec3d     elAzVector;
+        int	  diffSlots;
 
-	if( orbitPoints.isEmpty())//Setup orbitPoins
+
+	if (orbitPoints.isEmpty())//Setup orbitPoins
 	{
-		epochTm  = epochTime - orbitSpan;
+                epochTm  = epoch - orbitSpan;
 
-		for(int i=0; i<=orbitLineSegments; i++)
+		for (int i=0; i<=orbitLineSegments; i++)
 		{
-			pSatellite->setEpoch( epochTm);
-			azElVector  = observer.calculateLook( *pSatellite, epochTm);
-			orbitPoints.append(azElVector);
-			epochTm += computeInterval;
+			pSatWrapper->setEpoch(epochTm.getGmtTm());
+                        elAzVector  = pSatWrapper->getAltAz();
+                        orbitPoints.append(elAzVector);
+			epochTm    += computeInterval;
 		}
 		lastEpochCompForOrbit = epochTime;
 	}
-	else if( epochTime > lastEpochCompForOrbit)
+	else if (epochTime > lastEpochCompForOrbit)
 	{ // compute next orbit point when clock runs forward
 
-		gTimeSpan diffTime = epochTime - lastEpochCompForOrbit;
+                gTimeSpan diffTime = epoch - lastEpochComp;
 		diffSlots          = (int)(diffTime.getDblSeconds()/orbitLineSegmentDuration);
 
-		if(diffSlots > 0)
+		if (diffSlots > 0)
 		{
-			if( diffSlots > orbitLineSegments)
+			if (diffSlots > orbitLineSegments)
 			{
 				diffSlots = orbitLineSegments + 1;
-				epochTm   = epochTime - orbitSpan;
+                                epochTm  = epoch - orbitSpan;
 			}
 			else
 			{
-				epochTm   = lastEpochCompForOrbit + orbitSpan + computeInterval;
+				epochTm   = lastEpochComp + orbitSpan + computeInterval;
 			}
 
-			for( int i=0; i<diffSlots; i++)
+			for (int i=0; i<diffSlots; i++)
 			{  //remove points at beginning of list and add points at end.
 				orbitPoints.removeFirst();
-				pSatellite->setEpoch( epochTm);
-				azElVector  = observer.calculateLook( *pSatellite, epochTm);
-				orbitPoints.append(azElVector);
-				epochTm += computeInterval;
+				pSatWrapper->setEpoch(epochTm.getGmtTm());
+                                elAzVector  = pSatWrapper->getAltAz();
+                                orbitPoints.append(elAzVector);
+				epochTm    += computeInterval;
 			}
 
 			lastEpochCompForOrbit = epochTime;
 		}
 	}
-	else if(epochTime < lastEpochCompForOrbit)
+	else if (epochTime < lastEpochCompForOrbit)
 	{ // compute next orbit point when clock runs backward
-		gTimeSpan diffTime =  lastEpochCompForOrbit - epochTime;
+                gTimeSpan diffTime = lastEpochComp - epoch;
 		diffSlots          = (int)(diffTime.getDblSeconds()/orbitLineSegmentDuration);
 
-		if(diffSlots > 0)
+		if (diffSlots > 0)
 		{
-			if( diffSlots > orbitLineSegments)
+			if (diffSlots > orbitLineSegments)
 			{
 				diffSlots = orbitLineSegments + 1;
-				epochTm   = epochTime + orbitSpan;
+                                epochTm   = epoch + orbitSpan;
 			}
 			else
 			{
-				epochTm   = epochTime - orbitSpan - computeInterval;
+                                epochTm   = epoch - orbitSpan - computeInterval;
 			}
-			for( int i=0; i<diffSlots;i++)
+			for (int i=0; i<diffSlots; i++)
 			{ //remove points at end of list and add points at beginning.
 				orbitPoints.removeLast();
-				pSatellite->setEpoch( epochTm);
-				azElVector  = observer.calculateLook( *pSatellite, epochTm);
-				orbitPoints.push_front(azElVector);
+				pSatWrapper->setEpoch(epochTm.getGmtTm());
+                                elAzVector  = pSatWrapper->getAltAz();
+                                orbitPoints.push_front(elAzVector);
 				epochTm -= computeInterval;
 
 			}
