@@ -1,17 +1,17 @@
 /*
  * Stellarium
  * Copyright (C) 2009 Matthew Gates
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
@@ -32,10 +32,7 @@
 #include "StelSphereGeometry.hpp"
 
 #include "StelPainter.hpp"
-#include "gsatellite/gSatTEME.hpp"
-#include "gsatellite/gObserver.hpp"
-#include "gsatellite/gTime.hpp"
-#include "gsatellite/gVector.hpp"
+#include "gSatWrapper.hpp"
 
 
 class StelPainter;
@@ -54,8 +51,8 @@ typedef struct
 //! a map of data from the json file.
 class Satellite : public StelObject
 {
-friend class Satellites;
-friend class SatellitesDialog;
+	friend class Satellites;
+	friend class SatellitesDialog;
 public:
 	//! @param id The official designation for a satellite, e.g. "ZARYA"
 	//! @param conf a pointer to a QSettings object which contains the
@@ -67,8 +64,11 @@ public:
 	//! create a duplicate.
 	QVariantMap getMap(void);
 
-	virtual QString getType(void) const {return "Satellite";}
-	virtual float getSelectPriority(const StelNavigator *nav) const;
+	virtual QString getType(void) const
+	{
+		return "Satellite";
+	}
+	virtual float getSelectPriority(const StelCore* core) const;
 
 	//! Get an HTML string to describe the object
 	//! @param core A pointer to the core
@@ -77,15 +77,24 @@ public:
 	//! - Name: designation in large type with the description underneath
 	//! - RaDecJ2000, RaDecOfDate, HourAngle, AltAzi
 	//! - Extra1: range, rage rate and altitude of satellite above the Earth
-	//! - Extra2: Comms frequencies, modulation types and so on. 
+	//! - Extra2: Comms frequencies, modulation types and so on.
 	virtual QString getInfoString(const StelCore *core, const InfoStringGroup& flags) const;
 	virtual Vec3f getInfoColor(void) const;
-	virtual Vec3d getJ2000EquatorialPos(const StelNavigator *) const {return XYZ;}
-	virtual float getVMagnitude(const StelNavigator* nav=NULL) const;
+	virtual Vec3d getJ2000EquatorialPos(const StelCore*) const
+	{
+		return XYZ;
+	}
+	virtual float getVMagnitude(const StelCore* core=NULL) const;
 	virtual double getAngularSize(const StelCore* core) const;
-	virtual QString getNameI18n(void) const {return designation;}
-	virtual QString getEnglishName(void) const {return designation;}
-	
+	virtual QString getNameI18n(void) const
+	{
+		return designation;
+	}
+	virtual QString getEnglishName(void) const
+	{
+		return designation;
+	}
+
 	//! Set new tleElements.  This assumes the designation is already set, populates
 	//! the tleElements values and configures internal orbit parameters.
 	void setNewTleElements(const QString& tle1, const QString& tle2);
@@ -117,45 +126,43 @@ private:
 	bool visible;
 	bool orbitVisible;  //draw orbit enabled/disabled
 
-	QString designation;               // The ID of the satllite
+	QString designation;               // The ID of the satellite
 	QString description;               // longer description of spacecraft
 	Vec3d XYZ;                         // holds J2000 position
 	QPair< QByteArray, QByteArray > tleElements;
-	double height, velocity, azimuth, elevation, range, rangeRate;
+	double height, range, rangeRate;
 	QList<commLink> comms;
 	Vec3f hintColor;
 	QStringList groupIDs;
 	QDateTime lastUpdated;
-	
+
 	static StelTextureSP hintTexture;
+	static SphericalCap  viewportHalfspace;
 	static float hintBrightness;
 	static float hintScale;
-	static SphericalCap viewportHalfspace;
-	static int orbitLineSegments;
-	static int orbitLineFadeSegments;
-	static int orbitLineSegmentDuration;
-	static bool orbitLinesFlag;
+	static int   orbitLineSegments;
+	static int   orbitLineFadeSegments;
+	static int   orbitLineSegmentDuration; //measured in seconds
+	static bool  orbitLinesFlag;
 
 	void draw(const StelCore* core, StelPainter& painter, float maxMagHints);
-	void setObserverLocation(StelLocation* loc=NULL);
 
-
-	//gsatellite objects
-	gSatTEME *pSatellite;
-	gObserver observer;
-	gTime     epochTime;
-	gVector   Position;
-	gVector   Vel;
-	gVector   LatLong;
-	gVector   azElPos;
+        //Satellite Orbit Position calculation
+        gSatWrapper *pSatWrapper;
+        Vec3d position;
+        Vec3d velocity;
+        Vec3d latLongSubPointPosition;
+        Vec3d elAzPosition;
+        int   visibility;
 
 	//Satellite Orbit Draw
 	QFont     font;
 	Vec3f     orbitColorNormal;
 	Vec3f     orbitColorNight;
 	Vec3f*    orbitColor;
-	gTime     lastEpochCompForOrbit;
-	QList<gVector> orbitPoints; //orbit points represented by azElPos vectors
+	double    lastEpochCompForOrbit; //measured in Julian Days
+	double    epochTime;  //measured in Julian Days
+	QList<Vec3d> orbitPoints; //orbit points represented by ElAzPos vectors
 
 };
 
