@@ -19,7 +19,6 @@
 
 #include "StelLogger.hpp"
 
-#include <config.h>
 #include <QDateTime>
 #include <QProcess>
 #ifdef Q_OS_WIN
@@ -86,6 +85,9 @@ void StelLogger::init(const QString& logFilePath)
 		case QSysInfo::MV_10_5:
 			writeLog("Mac OS X 10.5");
 			break;
+		case QSysInfo::MV_10_6:
+			writeLog("Mac OS X 10.6");
+			break;
 		default:
 			writeLog("Unsupported Mac version");
 			break;
@@ -127,6 +129,8 @@ void StelLogger::init(const QString& logFilePath)
 
 	// write memory and CPU info
 #ifdef Q_OS_LINUX
+
+#ifndef BUILD_FOR_MAEMO
 	QFile infoFile("/proc/meminfo");
 	if(!infoFile.open(QIODevice::ReadOnly | QIODevice::Text))
 		writeLog("Could not get memory info.");
@@ -178,6 +182,7 @@ void StelLogger::init(const QString& logFilePath)
 			}
 		}
 	}
+#endif
 
 	// Aargh Windows API
 #elif defined Q_OS_WIN
@@ -251,10 +256,11 @@ void StelLogger::init(const QString& logFilePath)
 
 void StelLogger::deinit()
 {
+	qInstallMsgHandler(0);
 	logFile.close();
 }
 
-void StelLogger::debugLogHandler(QtMsgType type, const char* msg)
+void StelLogger::debugLogHandler(QtMsgType, const char* msg)
 {
 	fprintf(stderr, "%s\n", msg);
 	writeLog(QString(msg));
