@@ -101,6 +101,10 @@ Q_IMPORT_PLUGIN(SolarSystemEditor)
 Q_IMPORT_PLUGIN(TimeZoneConfiguration)
 #endif
 
+#ifdef USE_STATIC_PLUGIN_SUPERNOVAS
+Q_IMPORT_PLUGIN(Supernovas)
+#endif
+
 // Initialize static variables
 StelMainGraphicsView* StelMainGraphicsView::singleton = NULL;
 
@@ -155,7 +159,7 @@ StelMainGraphicsView::StelMainGraphicsView(QWidget* parent)
 	  flagInvertScreenShotColors(false),
 	  screenShotPrefix("stellarium-"),
 	  screenShotDir(""),
-	  cursorTimeout(-1.f), flagCursorTimeout(false), minFpsTimer(NULL), maxfps(10000.f), doPaint(true)
+	  cursorTimeout(-1.f), flagCursorTimeout(false), minFpsTimer(NULL), maxfps(10000.f)
 {
 	StelApp::initStatic();
 
@@ -289,10 +293,7 @@ void StelMainGraphicsView::thereWasAnEvent()
 void StelMainGraphicsView::drawBackground(QPainter*, const QRectF&)
 {
 	const double now = StelApp::getTotalRunTime();
-	if(!doPaint)
-	{
-	  return;
-	}
+
 	// Determines when the next display will need to be triggered
 	// The current policy is that after an event, the FPS is maximum for 2.5 seconds
 	// after that, it switches back to the default minfps value to save power
@@ -316,23 +317,6 @@ void StelMainGraphicsView::drawBackground(QPainter*, const QRectF&)
 	}
 }
 
-void StelMainGraphicsView::setDoPaint(bool doPainting)
-{
-        doPaint = doPainting;
-	mainSkyItem->setDoPaint(doPainting);
-	if (minFpsTimer==NULL)
-	  return;
-
-        if (!doPaint)
-        {
-                minFpsTimer->stop();
-        }
-        else
-        {
-                minFpsTimer->start();
-        }
-}
-
 void StelMainGraphicsView::startMainLoop()
 {
 	// Set a timer refreshing for every minfps frames
