@@ -58,7 +58,6 @@ public:
 	//! Use its layout if you want to add widget on the side of the main sky view.
 	QGraphicsWidget* getTopLevelGraphicsWidget() {return backItem;}
 
-        void setDoPaint(bool doPainting);
 #ifndef DISABLE_SCRIPTING
 	//! Get the script API proxy (for signal handling)
 	StelMainScriptAPIProxy* getMainScriptAPIProxy() {return scriptAPIProxy;}
@@ -187,7 +186,6 @@ private:
 	float minfps;
 	//! The maximum desired frame rate in frame per second.
 	float maxfps;
-        bool doPaint;
 };
 
 
