@@ -221,7 +221,7 @@ void StelApp::init(QSettings* conf)
 	textureMgr->init();
 
 #ifdef BUILD_FOR_MAEMO
-	StelLoadingBar loadingBar("textures/logoMaemo.png", PACKAGE_VERSION, 25, 520, 101, 800, 480);
+	StelLoadingBar loadingBar("textures/logo24bits.png", "", 25, 320, 101, 800, 400);
 #else
  #ifdef BZR_REVISION
 	StelLoadingBar loadingBar("textures/logo24bits.png", QString("BZR r%1").arg(BZR_REVISION), 25, 320, 101);
@@ -467,25 +467,13 @@ void StelApp::handleKeys(QKeyEvent* event)
 }
 
 
-// Set the colorscheme for all the modules
-void StelApp::setColorScheme(const QString& section)
-{
-	if (getGui())
-		getGui()->setStelStyle(section);
-	// Send the event to every StelModule
-	foreach (StelModule* iter, moduleMgr->getAllModules())
-	{
-		iter->setStelStyle(section);
-	}
-}
-
 //! Set flag for activating night vision mode
 void StelApp::setVisionModeNight(bool b)
 {
 	if (flagNightVision!=b)
 	{
 		flagNightVision=b;
-		setColorScheme(b ? "night_color" : "color");
+		emit(colorSchemeChanged(b ? "night_color" : "color"));
 	}
 }
 
@@ -493,13 +481,7 @@ void StelApp::setVisionModeNight(bool b)
 void StelApp::updateI18n()
 {
 #ifdef ENABLE_NLS
-	// Send the event to every StelModule
-	foreach (StelModule* iter, moduleMgr->getAllModules())
-	{
-		iter->updateI18n();
-	}
-	if (getGui())
-		getGui()->updateI18n();
+	emit(languageChanged());
 #endif
 }
 
@@ -507,11 +489,7 @@ void StelApp::updateI18n()
 void StelApp::updateSkyCulture()
 {
 	QString skyCultureDir = getSkyCultureMgr().getCurrentSkyCultureID();
-	// Send the event to every StelModule
-	foreach (StelModule* iter, moduleMgr->getAllModules())
-	{
-		iter->updateSkyCulture(skyCultureDir);
-	}
+	emit(skyCultureChanged(skyCultureDir));
 }
 
 // Return the time since when stellarium is running in second.
