@@ -32,7 +32,7 @@
 #include <QSettings>
 
 StelAppGraphicsWidget::StelAppGraphicsWidget()
-	: paintState(0), useBuffers(false), backgroundBuffer(NULL), foregroundBuffer(NULL), viewportEffect(NULL)
+	: paintState(0), useBuffers(false), backgroundBuffer(NULL), foregroundBuffer(NULL), viewportEffect(NULL), doPaint(true)
 {
 	previousPaintTime = StelApp::getTotalRunTime();
 	setFocusPolicy(Qt::StrongFocus);
@@ -55,10 +55,10 @@ StelAppGraphicsWidget::~StelAppGraphicsWidget()
 
 void StelAppGraphicsWidget::init(QSettings* conf)
 {
+	stelApp->init(conf);
 	Q_ASSERT(viewportEffect==NULL);
 	setViewportEffect(conf->value("video/viewport_effect", "none").toString());
-	stelApp->init(conf);
-
+	
 	//previousPaintTime needs to be updated after the time zone is set
 	//in StelLocaleMgr::init(), otherwise this causes an invalid value of
 	//deltaT the first time it is calculated in paintPartial(), which in
@@ -157,9 +157,9 @@ bool StelAppGraphicsWidget::paintPartial()
 void StelAppGraphicsWidget::paint(QPainter* painter, const QStyleOptionGraphicsItem*, QWidget*)
 {
 	// Don't even try to draw if we don't have a core yet (fix a bug during splash screen)
-	if (!stelApp || !stelApp->getCore())
+	if (!stelApp || !stelApp->getCore() || !doPaint)
 		return;
-
+	
 	StelPainter::setQPainter(painter);
 
 	if (useBuffers)
@@ -241,6 +241,8 @@ void StelAppGraphicsWidget::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 void StelAppGraphicsWidget::mousePressEvent(QGraphicsSceneMouseEvent* event)
 {
 	// Apply distortion on the mouse position.
+	// Widget gets focus on clicked
+	setFocus();
 	QPointF pos = event->scenePos();
 	distortPos(&pos);
 	pos.setY(scene()->height() - 1 - pos.y());
