@@ -19,6 +19,7 @@
 #include "StelJsonParser.hpp"
 #include <QDebug>
 #include <QBuffer>
+#include <QDateTime>
 #include <stdexcept>
 
 class StelJsonParserInstance
@@ -248,6 +249,10 @@ QVariant StelJsonParserInstance::readOther()
 		return QVariant(false);
 	if (str=="null")
 		return QVariant();
+	QDateTime dt = QDateTime::fromString(str, Qt::ISODate);
+	if (dt.isValid())
+		return QVariant(dt);
+
 	throw std::runtime_error(qPrintable(QString("Invalid JSON value: \"")+str+"\""));
 }
 
@@ -323,6 +328,8 @@ QVariant StelJsonParserInstance::parse()
 	}
 }
 
+QHash<int, void (*)(const QVariant&, QIODevice*, int)> StelJsonParser::otherSerializer;
+
 // Serialize the passed QVariant as JSON into the output QIODevice
 void StelJsonParser::write(const QVariant& v, QIODevice* output, int indentLevel)
 {
@@ -362,6 +369,11 @@ void StelJsonParser::write(const QVariant& v, QIODevice* output, int indentLevel
 		case QVariant::Double:
 			output->write(v.toString().toUtf8());
 			break;
+		case QVariant::DateTime:
+		{
+			output->write(v.toDateTime().toString(Qt::ISODate).toUtf8());
+			break;
+		}
 		case QVariant::List:
 		{
 			output->putChar('[');
@@ -406,7 +418,14 @@ void StelJsonParser::write(const QVariant& v, QIODevice* output, int indentLevel
 			break;
 		}
 		default:
-			output->write("null");
+			QHash<int, void (*)(const QVariant&, QIODevice*, int)>::ConstIterator iter = otherSerializer.find(v.userType());
+			if (iter!=otherSerializer.constEnd())
+			{
+				iter.value()(v, output, indentLevel);
+			}
+			else
+				output->write("null");
+			//qDebug() << v.type() << v.userType() << v.typeName();
 			//qWarning() << "Cannot serialize QVariant of type " << v.typeName() << " in JSON";
 			break;
 	}
