@@ -139,7 +139,7 @@ void StelLocaleMgr::setAppLanguage(const QString& newAppLanguageName)
 void StelLocaleMgr::setSkyLanguage(const QString& newSkyLanguageName)
 {
 	// Update the translator with new locale name
-	skyTranslator = StelTranslator("stellarium", StelFileMgr::getLocaleDir(), newSkyLanguageName);
+	skyTranslator = StelTranslator("stellarium-skycultures", StelFileMgr::getLocaleDir(), newSkyLanguageName);
 	qDebug() << "Sky language is " << skyTranslator.getTrueLocaleName();
 	StelApp::getInstance().updateI18n();
 }
@@ -158,6 +158,11 @@ StelTranslator& StelLocaleMgr::getSkyTranslator()
 	return skyTranslator;
 }
 
+StelTranslator& StelLocaleMgr::getAppStelTranslator() const
+{
+	return StelTranslator::globalTranslator;
+}
+
 
 // Return the time in ISO 8601 format that is : %Y-%m-%d %H:%M:%S
 QString StelLocaleMgr::getISO8601TimeLocal(double JD) const
