@@ -19,6 +19,7 @@
 #include "StelApp.hpp"
 #include "StelFileMgr.hpp"
 #include "StelLocationMgr.hpp"
+#include "StelUtils.hpp"
 #include "kfilterdev.h"
 
 #include <QStringListModel>
@@ -35,6 +36,9 @@ StelLocationMgr::StelLocationMgr()
 
 	modelAllLocation = new QStringListModel(this);
 	modelAllLocation->setStringList(locations.keys());
+	
+	// Init to Paris France because it's the center of the world.
+	lastResortLocation = locationForSmallString("Paris, France");
 }
 
 void StelLocationMgr::generateBinaryLocationFile(const QString& fileName, bool isUserLocation, const QString& binFilePath) const
@@ -153,20 +157,51 @@ StelLocationMgr::~StelLocationMgr()
 {
 }
 
-const StelLocation StelLocationMgr::locationForSmallString(const QString& s) const
+const StelLocation StelLocationMgr::locationForSmallString(const QString& s, bool* ok) const
 {
 	QMap<QString, StelLocation>::const_iterator iter = locations.find(s);
 	if (iter==locations.end())
 	{
-		qWarning() << "Warning: location" << s << "is unknown";
-		return locations["Paris, France"];
+		if (ok)
+			*ok=false;
+		return lastResortLocation;
 	}
 	else
 	{
+		if (ok)
+			*ok = true;
 		return locations.value(s);
 	}
 }
 
+const StelLocation StelLocationMgr::locationForString(const QString& s, bool* ok) const
+{
+	bool myOk;
+	StelLocation ret = locationForSmallString(s, &myOk);
+	if (myOk)
+	{
+		if (ok)
+			*ok=true;
+		return ret;
+	}
+	// Maybe it is a coordinate set ? (e.g. GPS +41d51'00" -51d00'00" )
+	QRegExp reg("(.*)([\\+\\-](?:\\d+)d(?:\\d+)'(?:\\d+)\") ([\\+\\-](?:\\d+)d(?:\\d+)'(?:\\d+)\")");
+	reg.setMinimal(true);
+	if (!reg.exactMatch(s))
+	{
+		if (ok)
+			*ok=false;
+		return ret;
+	}
+	// We have a set of coordinates
+	ret.name = reg.capturedTexts()[1].trimmed();
+	ret.latitude = StelUtils::dmsStrToRad(reg.capturedTexts()[2]) * 180 / M_PI;
+	ret.longitude = StelUtils::dmsStrToRad(reg.capturedTexts()[3]) * 180 / M_PI;
+	if (ok)
+		*ok=true;
+	return ret;
+}
+
 // Get whether a location can be permanently added to the list of user locations
 bool StelLocationMgr::canSaveUserLocation(const StelLocation& loc) const
 {
