@@ -45,9 +45,16 @@ public:
 	//! Return the list of all loaded locations
 	QList<StelLocation> getAll() const {return locations.values();}
 
-	//! Return the StelLocation for the given row (match modelAllLocation index row)
-	const StelLocation locationForSmallString(const QString& s) const;
+	//! Return the StelLocation for a given string
+	//! Can match location name, or coordinates
+	const StelLocation locationForString(const QString& s, bool* ok=NULL) const;
 
+	//! Return the StelLocation for the given row (match modelAllLocation index row)
+	const StelLocation locationForSmallString(const QString& s, bool* ok=NULL) const;
+
+	//! Return a valid location when no valid one was found.
+	const StelLocation& getLastResortLocation() const {return lastResortLocation;}
+	
 	//! Get whether a location can be permanently added to the list of user locations
 	//! The main constraint is that the small string must be unique
 	bool canSaveUserLocation(const StelLocation& loc) const;
@@ -78,6 +85,8 @@ private:
 
 	//! The list of all loaded locations
 	QMap<QString, StelLocation> locations;
+	
+	StelLocation lastResortLocation;
 };
 
 #endif // _STELLOCATIONMGR_HPP_
