@@ -27,6 +27,7 @@
 
 #include <QGLFramebufferObject>
 #include <QSettings>
+#include <QFile>
 
 void StelViewportEffect::paintViewportBuffer(const QGLFramebufferObject* buf) const
 {
@@ -55,11 +56,11 @@ StelViewportDistorterFisheyeToSphericMirror::StelViewportDistorterFisheyeToSpher
 	// initialize viewport parameters and texture size:
 
 	// maximum FOV value of the not yet distorted image
-	double distorter_max_fov = conf.value("spheric_mirror/distorter_max_fov",175.0).toDouble();
-	if (distorter_max_fov > 240.0)
-		distorter_max_fov = 240.0;
-	else if (distorter_max_fov < 120.0)
-		distorter_max_fov = 120.0;
+	double distorter_max_fov = conf.value("spheric_mirror/distorter_max_fov",175.f).toFloat();
+	if (distorter_max_fov > 240.f)
+		distorter_max_fov = 240.f;
+	else if (distorter_max_fov < 120.f)
+		distorter_max_fov = 120.f;
 	if (distorter_max_fov > core->getMovementMgr()->getMaxFov())
 		distorter_max_fov = core->getMovementMgr()->getMaxFov();
 
@@ -89,11 +90,11 @@ StelViewportDistorterFisheyeToSphericMirror::StelViewportDistorterFisheyeToSpher
 	}
 
 	// center of the FOV-disk in the not yet distorted image
-	newProjectorParams.viewportCenter[0] = conf.value("spheric_mirror/viewportCenterX", 0.5*newProjectorParams.viewportXywh[2]).toDouble();
-	newProjectorParams.viewportCenter[1] = conf.value("spheric_mirror/viewportCenterY", 0.5*newProjectorParams.viewportXywh[3]).toDouble();
+	newProjectorParams.viewportCenter[0] = conf.value("spheric_mirror/viewportCenterX", 0.5*newProjectorParams.viewportXywh[2]).toFloat();
+	newProjectorParams.viewportCenter[1] = conf.value("spheric_mirror/viewportCenterY", 0.5*newProjectorParams.viewportXywh[3]).toFloat();
 
 	// diameter of the FOV-disk in pixels
-	newProjectorParams.viewportFovDiameter = conf.value("spheric_mirror/viewport_fov_diameter", qMin(newProjectorParams.viewportXywh[2],newProjectorParams.viewportXywh[3])).toDouble();
+	newProjectorParams.viewportFovDiameter = conf.value("spheric_mirror/viewport_fov_diameter", qMin(newProjectorParams.viewportXywh[2],newProjectorParams.viewportXywh[3])).toFloat();
 
 	texture_wh = 1;
 	while (texture_wh < newProjectorParams.viewportXywh[2] || texture_wh < newProjectorParams.viewportXywh[3])
@@ -111,11 +112,11 @@ StelViewportDistorterFisheyeToSphericMirror::StelViewportDistorterFisheyeToSpher
 	const QString custom_distortion_file = conf.value("spheric_mirror/custom_distortion_file","").toString();
 	if (custom_distortion_file.isEmpty())
 	{
-		double texture_triangle_base_length = conf.value("spheric_mirror/texture_triangle_base_length",16.0).toDouble();
-		if (texture_triangle_base_length > 256.0)
-			texture_triangle_base_length = 256.0;
-		else if (texture_triangle_base_length < 2.0)
-			texture_triangle_base_length = 2.0;
+		float texture_triangle_base_length = conf.value("spheric_mirror/texture_triangle_base_length",16.f).toFloat();
+		if (texture_triangle_base_length > 256.f)
+			texture_triangle_base_length = 256.f;
+		else if (texture_triangle_base_length < 2.f)
+			texture_triangle_base_length = 2.f;
 		max_x = (int)trunc(0.5 + screen_w/texture_triangle_base_length);
 		step_x = screen_w / (double)(max_x-0.5);
 		max_y = (int)trunc(screen_h/(texture_triangle_base_length*0.5*sqrt(3.0)));
@@ -138,7 +139,7 @@ StelViewportDistorterFisheyeToSphericMirror::StelViewportDistorterFisheyeToSpher
 				Vec2f &texture_point(texture_point_array[(j*(max_x+1)+i)]);
 				vertex_point.ver_xy[0] = ((i == 0) ? 0.f : (i == max_x) ? screen_w : (i-0.5f*(j&1))*step_x);
 				vertex_point.ver_xy[1] = j*step_y;
-				Vec3d v,vX,vY;
+				Vec3f v,vX,vY;
 				bool rc = calc.retransform(
 							  (vertex_point.ver_xy[0]-0.5f*screen_w) / screen_h,
 							  (vertex_point.ver_xy[1]-0.5f*screen_h) / screen_h, v,vX,vY);
