@@ -137,7 +137,7 @@ Atmosphere::~Atmosphere(void)
 void Atmosphere::computeColor(double JD, Vec3d _sunPos, Vec3d moonPos, float moonPhase,
 							   StelCore* core, float latitude, float altitude, float temperature, float relativeHumidity)
 {
-	const StelProjectorP prj = core->getProjection(StelCore::FrameAltAz);
+	const StelProjectorP prj = core->getProjection(StelCore::FrameAltAz, StelCore::RefractionOff);
 	if (viewport != prj->getViewport())
 	{
 		// The viewport changed: update the number of point of the grid
