@@ -26,7 +26,7 @@
 #include "StelProjector.hpp"
 #include "Constellation.hpp"
 #include "StarMgr.hpp"
-#include "StelNavigator.hpp"
+
 #include "StelTexture.hpp"
 #include "StelPainter.hpp"
 #include "StelApp.hpp"
@@ -88,14 +88,14 @@ bool Constellation::read(const QString& record, StarMgr *starMgr)
 	XYZname.set(0.,0.,0.);
 	for(unsigned int ii=0;ii<numberOfSegments*2;++ii)
 	{
-		XYZname+= asterism[ii]->getJ2000EquatorialPos(StelApp::getInstance().getCore()->getNavigator());
+		XYZname+= asterism[ii]->getJ2000EquatorialPos(StelApp::getInstance().getCore());
 	}
 	XYZname.normalize();
 
 	return true;
 }
 
-void Constellation::drawOptim(StelPainter& sPainter, const StelNavigator* nav, const SphericalCap& viewportHalfspace) const
+void Constellation::drawOptim(StelPainter& sPainter, const StelCore* core, const SphericalCap& viewportHalfspace) const
 {
 	if (lineFader.getInterstate()<=0.0001f)
 		return;
@@ -106,8 +106,8 @@ void Constellation::drawOptim(StelPainter& sPainter, const StelNavigator* nav, c
 	Vec3d star2;
 	for (unsigned int i=0;i<numberOfSegments;++i)
 	{
-		star1=asterism[2*i]->getJ2000EquatorialPos(nav);
-		star2=asterism[2*i+1]->getJ2000EquatorialPos(nav);
+		star1=asterism[2*i]->getJ2000EquatorialPos(core);
+		star2=asterism[2*i+1]->getJ2000EquatorialPos(core);
 		star1.normalize();
 		star2.normalize();
 		sPainter.drawGreatCircleArc(star1, star2, &viewportHalfspace);
