@@ -63,25 +63,6 @@ public:
 	//! Updates time-varying state for each Constellation.
 	virtual void update(double deltaTime);
 
-	//! Update i18n names from English names according to current
-	//! locale, and update font for locale.
-	//! The translation is done using gettext with translated strings defined
-	//! in translations.h
-	virtual void updateI18n();
-
-	//! Loads new constellation data and art if the SkyCulture has changed.
-	//! @param skyCultureDir the name of the directory containing the sky culture to use.
-	virtual void updateSkyCulture(const QString& skyCultureDir);
-
-	//! Limit the number of constellations to draw based on selected stars.
-	//! The selected objects changed, check if some stars are selected and display the
-	//! matching constellations if isolateSelected mode is activated.
-	//! @param action define whether to add to, replace, or remove from the existing selection
-	virtual void selectedObjectChangeCallBack(StelModuleSelectAction action = StelModule::ReplaceSelection);
-
-	//! Load a color scheme
-	virtual void setStelStyle(const QString& section);
-
 	//! Return the value defining the order of call for the given action
 	//! @param actionName the name of the action for which we want the call order
 	//! @return the value defining the order. The closer to 0 the earlier the module's action will be called
@@ -107,7 +88,7 @@ public:
 
 	///////////////////////////////////////////////////////////////////////////
 	// Properties setters and getters
-public slots:
+public slots:	
 	//! Set constellation art fade duration in second
 	void setArtFadeDuration(float duration);
 	//! Get constellation art fade duration in second
@@ -163,6 +144,26 @@ public slots:
 	//! Get the font size used for constellation names display
 	float getFontSize() const;
 
+private slots:
+	//! Limit the number of constellations to draw based on selected stars.
+	//! The selected objects changed, check if some stars are selected and display the
+	//! matching constellations if isolateSelected mode is activated.
+	//! @param action define whether to add to, replace, or remove from the existing selection
+	void selectedObjectChange(StelModule::StelModuleSelectAction action);
+
+	//! Load a color scheme
+	void setStelStyle(const QString& section);
+
+	//! Loads new constellation data and art if the SkyCulture has changed.
+	//! @param skyCultureDir the name of the directory containing the sky culture to use.
+	void updateSkyCulture(const QString& skyCultureDir);
+
+	//! Update i18n names from English names according to current
+	//! locale, and update font for locale.
+	//! The translation is done using gettext with translated strings defined
+	//! in translations.h
+	void updateI18n();
+
 private:
 	//! Read constellation names from the given file.
 	//! @param namesFile Name of the file containing the constellation names in english
@@ -189,7 +190,7 @@ private:
 	//! @param conCatFile the path to the file which contains the constellation boundary data.
 	bool loadBoundaries(const QString& conCatFile);
 	//! Draw the constellation lines at the epoch given by the StelNavigator.
-	void drawLines(StelPainter& sPainter, const StelNavigator* nav) const;
+	void drawLines(StelPainter& sPainter, const StelCore* core) const;
 	//! Draw the constellation art.
 	void drawArt(StelPainter& sPainter) const;
 	//! Draw the constellation name labels.
