@@ -24,7 +24,7 @@
 #include "VecMath.hpp"
 #include "StelToneReproducer.hpp"
 #include "StelProjector.hpp"
-#include "StelNavigator.hpp"
+
 #include "StelFader.hpp"
 #include "StelUtils.hpp"
 #include "StelTextureTypes.hpp"
@@ -71,6 +71,17 @@ public:
 
 	//! Return the associated location or NULL
 	const StelLocation& getLocation() const {return location;}
+  	//! Return default Bortle index (light pollution value) or -1 (unknown/no change)
+	int getDefaultBortleIndex() const {return defaultBortleIndex;}
+	//! Return default fog setting (0/1) or -1 (no change)
+	int getDefaultFogSetting() const {return defaultFogSetting;}
+  	//! Return default atmosperic extinction, mag/airmass, or -1 (no change)
+	float getDefaultAtmosphericExtinction() const {return defaultExtinctionCoefficient;}
+	//! Return default atmospheric temperature, for refraction computation, or -1000 for "unknown/no change".
+	float getDefaultAtmosphericTemperature() const {return defaultTemperature;}
+	//! Return default atmospheric temperature, for refraction computation.
+	//! returns -1 to signal "standard conditions", or -2 for "unknown/invalid/no change"
+	float getDefaultAtmosphericPressure() const {return defaultPressure;}
 
 	//! Set the z-axis rotation (offset from original value when rotated
 	void setZRotation(float d) {angleRotateZOffset = d;}
@@ -97,6 +108,11 @@ protected:
 	// GZ patched, these can now be set in landscape.ini:
 	int rows; // horizontal rows
 	int cols; // vertical columns
+        int defaultBortleIndex; // light pollution from landscape.ini, or -1(no change)
+        int defaultFogSetting; // fog flag setting from landscape.ini: -1(no change), 0(off), 1(on)
+        double defaultExtinctionCoefficient; // atmospheric_extinction_coefficient from landscape.ini or -1
+        double defaultTemperature; // atmospheric_temperature from landscape.ini or -1000.0
+        double defaultPressure; // atmospheric_pressure from landscape.ini or -1.0
 
 	typedef struct
 	{
