@@ -21,7 +21,7 @@
 #include "StelFader.hpp"
 #include "StelTexture.hpp"
 #include "StelUtils.hpp"
-#include "StelNavigator.hpp"
+
 #include "StelProjector.hpp"
 #include "StelToneReproducer.hpp"
 #include "StelApp.hpp"
@@ -69,11 +69,12 @@ bool MilkyWay::getFlagShow() const {return *fader;}
 
 void MilkyWay::draw(StelCore* core)
 {
-	StelNavigator* nav = core->getNavigator();
-	const StelProjectorP prj = core->getProjection(nav->getJ2000ModelViewMat()*
-			Mat4d::xrotation(M_PI/180*23)*
-			Mat4d::yrotation(M_PI/180*120)*
-			Mat4d::zrotation(M_PI/180*7));
+	StelProjector::ModelViewTranformP transfo = core->getJ2000ModelViewTransform();
+	transfo->combine(Mat4d::xrotation(M_PI/180.*23.)*
+					 Mat4d::yrotation(M_PI/180.*120.)*
+					 Mat4d::zrotation(M_PI/180.*7.));
+
+	const StelProjectorP prj = core->getProjection(transfo);
 	StelToneReproducer* eye = core->getToneReproducer();
 
 	Q_ASSERT(tex);	// A texture must be loaded before calling this
