@@ -1,6 +1,7 @@
 /*
  * Stellarium
  * Copyright (C) 2002 Fabien Chereau
+ * Copyright (C) 2011 Alexander Wolf
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -65,15 +66,6 @@ public:
 	//! Update state which is time dependent.
 	virtual void update(double deltaTime) {hintsFader.update((int)(deltaTime*1000)); flagShow.update((int)(deltaTime*1000));}
 
-	//! Update i18 names from English names according to passed translator.
-	//! The translation is done using gettext with translated strings defined
-	//! in translations.h
-	virtual void updateI18n();
-
-	//! Sets the colors of the Nebula labels and markers according to the
-	//! values in a configuration object
-	virtual void setStelStyle(const QString& section);
-
 	//! Determines the order in which the various modules are drawn.
 	virtual double getCallOrder(StelModuleActionName actionName) const;
 
@@ -153,6 +145,17 @@ public slots:
 	//! @return the amount between 0 and 10. 0 is no hints, 10 is maximum of hints
 	float getHintsAmount(void) const {return hintsAmount;}
 
+private slots:
+	//! Sets the colors of the Nebula labels and markers according to the
+	//! values in a configuration object
+	void setStelStyle(const QString& section);
+
+	//! Update i18 names from English names according to passed translator.
+	//! The translation is done using gettext with translated strings defined
+	//! in translations.h
+	void updateI18n();
+	
+
 private:
 	//! Search for a nebula object by name. e.g. M83, NGC 1123, IC 1234.
 	NebulaP search(const QString& name);
