@@ -23,6 +23,7 @@
 #include <QString>
 
 #include "StelObject.hpp"
+#include "StelProjector.hpp"
 #include "VecMath.hpp"
 #include "StelFader.hpp"
 #include "StelTextureTypes.hpp"
@@ -32,7 +33,7 @@
 // The last variable is the userData pointer.
 typedef void (*posFuncType)(double, double*, void*);
 
-typedef void (OsulatingFunctType)(double jd0,double jd,double xyz[3]);
+typedef void (OsculatingFunctType)(double jd0,double jd,double xyz[3]);
 
 // epoch J2000: 12 UT on 1 Jan 2000
 #define J2000 2451545.0
@@ -69,7 +70,7 @@ class Ring
 public:
 	Ring(double radiusMin,double radiusMax,const QString &texname);
 	~Ring(void);
-	void draw(StelPainter* painter,const Mat4d& mat,double screenSz);
+	void draw(StelPainter* painter, StelProjector::ModelViewTranformP transfo, double screenSz);
 	double getSize(void) const {return radiusMax;}
 private:
 	const double radiusMin;
@@ -91,7 +92,7 @@ public:
 		   const QString& texMapName,
 		   posFuncType _coordFunc,
 		   void* userDataPtr,
-		   OsulatingFunctType *osculatingFunc,
+		   OsculatingFunctType *osculatingFunc,
 		   bool closeOrbit,
 		   bool hidden,
 		   bool hasAtmosphere);
@@ -109,18 +110,20 @@ public:
 	//! - Distance
 	//! - Size
 	//! - PlainText
-	//! @param core the Stelore object
+        //! - Extra1: Heliocentric Ecliptical Coordinates
+        //! - Extra2: Observer-planetocentric Ecliptical Coordinates
+	//! @param core the StelCore object
 	//! @param flags a set of InfoStringGroup items to include in the return value.
 	//! @return a QString containing an HMTL encoded description of the Planet.
 	virtual QString getInfoString(const StelCore *core, const InfoStringGroup& flags) const;
-	virtual double getCloseViewFov(const StelNavigator * nav) const;
-	virtual double getSatellitesFov(const StelNavigator * nav) const;
-	virtual double getParentSatellitesFov(const StelNavigator * nav) const;
-	virtual float getVMagnitude(const StelNavigator * nav) const;
-	virtual float getSelectPriority(const StelNavigator *nav) const;
+	virtual double getCloseViewFov(const StelCore* core) const;
+	virtual double getSatellitesFov(const StelCore* core) const;
+	virtual double getParentSatellitesFov(const StelCore* core) const;
+	virtual float getVMagnitude(const StelCore* core) const;
+	virtual float getSelectPriority(const StelCore* core) const;
 	virtual Vec3f getInfoColor(void) const;
 	virtual QString getType(void) const {return "Planet";}
-	virtual Vec3d getJ2000EquatorialPos(const StelNavigator *nav) const;
+	virtual Vec3d getJ2000EquatorialPos(const StelCore *core) const;
 	virtual QString getEnglishName(void) const {return englishName;}
 	virtual QString getNameI18n(void) const {return nameI18;}
 	virtual double getAngularSize(const StelCore* core) const;
@@ -164,7 +167,8 @@ public:
 
 	// Set the orbital elements
 	void setRotationElements(float _period, float _offset, double _epoch,
-		float _obliquity, float _ascendingNode, float _precessionRate, double _siderealPeriod);
+				 float _obliquity, float _ascendingNode,
+				 float _precessionRate, double _siderealPeriod);
 	double getRotAscendingnode(void) const {return re.ascendingNode;}
 	double getRotObliquity(void) const {return re.obliquity;}
 
@@ -210,10 +214,10 @@ public:
 	double lastOrbitJD;
 	double deltaJD;
 	double deltaOrbitJD;
-	bool orbitCached;              // whether orbit calculations are cached for drawing orbit yet
-	bool closeOrbit;               // whether to connect the beginning of the orbit line to
-								   // the end: good for elliptical orbits, bad for parabolic
-								   // and hyperbolic orbits
+	bool orbitCached;                // whether orbit calculations are cached for drawing orbit yet
+	bool closeOrbit;                 // whether to connect the beginning of the orbit line to
+					 // the end: good for elliptical orbits, bad for parabolic
+					 // and hyperbolic orbits
 
 	static Vec3f orbitColor;
 	static void setOrbitColor(const Vec3f& oc) {orbitColor = oc;}
@@ -226,10 +230,10 @@ protected:
 	void drawEarthShadow(StelCore* core, StelPainter* sPainter);
 
 	// Return the information string "ready to print" :)
-	QString getSkyLabel(const StelNavigator * nav) const;
+	QString getSkyLabel(const StelCore* core) const;
 
 	// Draw the 3d model. Call the proper functions if there are rings etc..
-	void draw3dModel(StelCore* core, const Mat4d& mat, float screenSz);
+	void draw3dModel(StelCore* core, StelProjector::ModelViewTranformP transfo, float screenSz);
 
 	// Draw the 3D sphere
 	void drawSphere(StelPainter* painter, float screenSz);
@@ -237,39 +241,39 @@ protected:
 	// Draw the circle and name of the Planet
 	void drawHints(const StelCore* core, const QFont& planetNameFont);
 
-	QString englishName;            // english planet name
-	QString nameI18;                // International translated name
-	QString texMapName;				// Texture file path
-	int flagLighting;               // Set whether light computation has to be proceed
-	RotationElements re;            // Rotation param
-	double radius;                  // Planet radius in UA
-	double oneMinusOblateness;      // (polar radius)/(equatorial radius)
-	Vec3d eclipticPos;             // Position in UA in the rectangular ecliptic coordinate system
-									// centered on the parent Planet
-	Vec3d screenPos;                // Used to store temporarily the 2D position on screen
-	Vec3d previousScreenPos;        // The position of this planet in the previous frame.
+	QString englishName;             // english planet name
+	QString nameI18;                 // International translated name
+	QString texMapName;              // Texture file path
+	int flagLighting;                // Set whether light computation has to be proceed
+	RotationElements re;             // Rotation param
+	double radius;                   // Planet radius in AU
+	double oneMinusOblateness;       // (polar radius)/(equatorial radius)
+	Vec3d eclipticPos;               // Position in AU in the rectangular ecliptic coordinate system
+					 // centered on the parent Planet
+	Vec3d screenPos;                 // Used to store temporarily the 2D position on screen
+	Vec3d previousScreenPos;         // The position of this planet in the previous frame.
 	Vec3f color;
-	float albedo;                   // Planet albedo
+	float albedo;                    // Planet albedo
 	Mat4d rotLocalToParent;
-	float axisRotation;            // Rotation angle of the Planet on it's axis
-	StelTextureSP texMap;             // Planet map texture
-	Ring* rings;                    // Planet rings
-	double distance;                // Temporary variable used to store the distance to a given point
-									// it is used for sorting while drawing
-	float sphereScale;             // Artificial scaling for better viewing
+	float axisRotation;              // Rotation angle of the Planet on it's axis
+	StelTextureSP texMap;            // Planet map texture
+	Ring* rings;                     // Planet rings
+	double distance;                 // Temporary variable used to store the distance to a given point
+					 // it is used for sorting while drawing
+	float sphereScale;               // Artificial scaling for better viewing
 	double lastJD;
 	// The callback for the calculation of the equatorial rect heliocentric position at time JD.
 	posFuncType coordFunc;
 	void* userDataPtr;
 
-	OsulatingFunctType *const osculatingFunc;
+	OsculatingFunctType *const osculatingFunc;
 	QSharedPointer<Planet> parent;           // Planet parent i.e. sun for earth
 	QList<QSharedPointer<Planet> > satellites;      // satellites of the Planet
 	LinearFader hintFader;
-	LinearFader labelsFader;        // Store the current state of the label for this planet
-	bool flagLabels;                // Define whether labels should be displayed
-	bool hidden;                    // useful for fake planets used as observation positions - not drawn or labeled
-	bool atmosphere;                // Does the planet have an atmosphere?
+	LinearFader labelsFader;         // Store the current state of the label for this planet
+	bool flagLabels;                 // Define whether labels should be displayed
+	bool hidden;                     // useful for fake planets used as observation positions - not drawn or labeled
+	bool atmosphere;                 // Does the planet have an atmosphere?
 
 	static Vec3f labelColor;
 	static StelTextureSP hintCircleTex;
