@@ -88,17 +88,6 @@ public:
 	//! Includes fading in and out stars and labels when they are turned on and off.
 	virtual void update(double deltaTime) {labelsFader.update((int)(deltaTime*1000)); starsFader.update((int)(deltaTime*1000));}
 
-	//! Translate text.
-	virtual void updateI18n();
-
-	//! Called when the sky culture is updated.
-	//! Loads common and scientific names of stars for a given sky culture.
-	//! @param skyCultureDir the name of the directory containing the sky culture to use.
-	virtual void updateSkyCulture(const QString& skyCultureDir);
-
-	//! Load a color scheme
-	virtual void setStelStyle(const QString& section);
-
 	//! Used to determine the order in which the various StelModules are drawn.
 	virtual double getCallOrder(StelModuleActionName actionName) const;
 
@@ -182,6 +171,16 @@ public:
 	//! @return false in case of failure.
 	bool checkAndLoadCatalog(QVariantMap m);
 
+private slots:
+	void setStelStyle(const QString& section);
+	//! Translate text.
+	void updateI18n();
+
+	//! Called when the sky culture is updated.
+	//! Loads common and scientific names of stars for a given sky culture.
+	//! @param skyCultureDir the name of the directory containing the sky culture to use.
+	void updateSkyCulture(const QString& skyCultureDir);
+
 private:
 
 	void setCheckFlag(const QString& catalogId, bool b);
@@ -206,7 +205,7 @@ private:
 	void loadData(QVariantMap starsConfigFile);
 
 	//! Draw a nice animated pointer around the object.
-	void drawPointer(StelPainter& sPainter, const StelNavigator * nav);
+	void drawPointer(StelPainter& sPainter, const StelCore* core);
 
 	LinearFader labelsFader;
 	LinearFader starsFader;
