@@ -27,8 +27,6 @@
 #include <QGraphicsSceneMouseEvent>
 #include <QSettings>
 #include <QTextDocument>
-#include "StelModuleMgr.hpp"
-#include "StelObjectMgr.hpp"
 
 InfoPanel::InfoPanel(QGraphicsItem* parent) : QGraphicsTextItem("", parent)
 {
@@ -46,9 +44,6 @@ InfoPanel::InfoPanel(QGraphicsItem* parent) : QGraphicsTextItem("", parent)
 		qWarning() << "config.ini option gui/selected_object_info is invalid, using \"all\"";
 		infoTextFilters = StelObject::InfoStringGroup(StelObject::AllInfo);
 	}
-#ifdef BUILD_FOR_MAEMO
-	setFont(QFont("SmallSystemFont"));
-#endif
 }
 
 void InfoPanel::setTextFromObjects(const QList<StelObjectP>& selected)
@@ -66,12 +61,6 @@ void InfoPanel::setTextFromObjects(const QList<StelObjectP>& selected)
 	}
 }
 
-void InfoPanel::mousePressEvent(QGraphicsSceneMouseEvent* event)
-{
-  GETSTELMODULE(StelObjectMgr)->unSelect();
-  event->accept();
-}
-
 SkyGui::SkyGui(QGraphicsItem * parent): QGraphicsWidget(parent), stelGui(NULL)
 {
 	setObjectName("StelSkyGui");
@@ -149,6 +138,7 @@ void SkyGui::init(StelGui* astelGui)
 
 	buttonBarPath->setZValue(-0.1);
 	updateBarsPos();
+	connect(&StelApp::getInstance(), SIGNAL(colorSchemeChanged(const QString&)), this, SLOT(setStelStyle(const QString&)));
 }
 
 void SkyGui::resizeEvent(QGraphicsSceneResizeEvent* event)
@@ -238,9 +228,9 @@ void SkyGui::updateBarsPos()
 	autoHidebts->setOpacity(opacity < 0.01 ? 0.01 : opacity);	// Work around a qt bug
 }
 
-void SkyGui::setStelStyle(const StelStyle& style)
+void SkyGui::setStelStyle(const QString& style)
 {
-	if (style.confSectionName=="night_color")
+	if (style == "night_color")
 	{
 		buttonBarPath->setPen(QColor::fromRgbF(0.7,0.2,0.2,0.5));
 		buttonBarPath->setBrush(QColor::fromRgbF(0.23, 0.13, 0.03, 0.2));
