@@ -42,7 +42,6 @@ class InfoPanel : public QGraphicsTextItem
 		void setInfoTextFilters(const StelObject::InfoStringGroup& aflags) {infoTextFilters=aflags;}
 		const StelObject::InfoStringGroup& getInfoTextFilters(void) const {return infoTextFilters;}
 		void setTextFromObjects(const QList<StelObjectP>&);
-	virtual void mousePressEvent(QGraphicsSceneMouseEvent* event);
 	private:
 		StelObject::InfoStringGroup infoTextFilters;
 };
@@ -63,9 +62,6 @@ public:
 	
 	void init(class StelGui* stelGui);
 	
-	//! Load color scheme from the given ini file and section name
-	void setStelStyle(const StelStyle& style);
-
 	virtual void paint(QPainter*, const QStyleOptionGraphicsItem*, QWidget* = 0);
 	
 protected:
@@ -73,6 +69,9 @@ protected:
 	virtual void hoverMoveEvent(QGraphicsSceneHoverEvent* event);
 
 private slots:
+	//! Load color scheme from the given ini file and section name
+	void setStelStyle(const QString& style);
+	
 	//! Update the position of the button bars in the main window
 	void updateBarsPos();
 	
