@@ -35,7 +35,7 @@
 #include "GridLinesMgr.hpp"
 #include "NebulaMgr.hpp"
 #include "StelLocaleMgr.hpp"
-#include "StelNavigator.hpp"
+
 #include "StelObjectType.hpp"
 #include "StelObject.hpp"
 #include "StelProjector.hpp"
@@ -108,6 +108,7 @@ void StelGui::init(QGraphicsWidget* atopLevelGraphicsWidget, StelAppGraphicsWidg
 	addGuiActions("actionShow_Ecliptic_Line", N_("Ecliptic line"), ",", group, true, false);
 	addGuiActions("actionShow_Equator_Line", N_("Equator line"), ".", group, true, false);
 	addGuiActions("actionShow_Meridian_Line", N_("Meridian line"), ";", group, true, false);
+	addGuiActions("actionShow_Horizon_Line", N_("Horizon line"), "", group, true, false);
 	addGuiActions("actionShow_Cardinal_Points", N_("Cardinal points"), "Q", group, true, false);
 
 	addGuiActions("actionShow_Ground", N_("Ground"), "G", group, true, false);
@@ -162,8 +163,8 @@ void StelGui::init(QGraphicsWidget* atopLevelGraphicsWidget, StelAppGraphicsWidg
 	group = N_("Movement and Selection");
 	addGuiActions("actionGoto_Selected_Object", N_("Center on selected object"), "Space", group, false, false);
 	addGuiActions("actionSet_Tracking", N_("Track object"), "T", group, true, false);
-	addGuiActions("actionZoom_In_Auto", N_("Zoom in on selected object"), "Ctrl+V", group, false, false);
-	addGuiActions("actionZoom_Out_Auto", N_("Zoom out"), "Ctrl+B", group, false, false);
+	addGuiActions("actionZoom_In_Auto", N_("Zoom in on selected object"), "/", group, false, false);
+	addGuiActions("actionZoom_Out_Auto", N_("Zoom out"), "\\", group, false, false);
 	addGuiActions("actionSet_Home_Planet_To_Selected", N_("Set home planet to selected planet"), "Ctrl+G", group, false, false);
 
 	group = N_("Miscellaneous");
@@ -205,6 +206,8 @@ void StelGui::init(QGraphicsWidget* atopLevelGraphicsWidget, StelAppGraphicsWidg
 	getGuiActions("actionShow_Equator_Line")->setChecked(gmgr->getFlagEquatorLine());
 	connect(getGuiActions("actionShow_Meridian_Line"), SIGNAL(toggled(bool)), gmgr, SLOT(setFlagMeridianLine(bool)));
 	getGuiActions("actionShow_Meridian_Line")->setChecked(gmgr->getFlagMeridianLine());
+	connect(getGuiActions("actionShow_Horizon_Line"), SIGNAL(toggled(bool)), gmgr, SLOT(setFlagHorizonLine(bool)));
+	getGuiActions("actionShow_Horizon_Line")->setChecked(gmgr->getFlagHorizonLine());
 	connect(getGuiActions("actionShow_Equatorial_J2000_Grid"), SIGNAL(toggled(bool)), gmgr, SLOT(setFlagEquatorJ2000Grid(bool)));
 	getGuiActions("actionShow_Equatorial_J2000_Grid")->setChecked(gmgr->getFlagEquatorJ2000Grid());
 	connect(getGuiActions("actionShow_Galactic_Grid"), SIGNAL(toggled(bool)), gmgr, SLOT(setFlagGalacticGrid(bool)));
@@ -228,31 +231,32 @@ void StelGui::init(QGraphicsWidget* atopLevelGraphicsWidget, StelAppGraphicsWidg
 	connect(getGuiActions("actionShow_DSS"), SIGNAL(toggled(bool)), imgr, SLOT(setFlagShow(bool)));
 	getGuiActions("actionShow_DSS")->setChecked(imgr->getFlagShow());
 
+
+	StelCore* core = StelApp::getInstance().getCore();
 	StelMovementMgr* mmgr = GETSTELMODULE(StelMovementMgr);
-	StelNavigator* nav = StelApp::getInstance().getCore()->getNavigator();
 	connect(getGuiActions("actionIncrease_Script_Speed"), SIGNAL(triggered()), this, SLOT(increaseScriptSpeed()));
 	connect(getGuiActions("actionDecrease_Script_Speed"), SIGNAL(triggered()), this, SLOT(decreaseScriptSpeed()));
 	connect(getGuiActions("actionSet_Real_Script_Speed"), SIGNAL(triggered()), this, SLOT(setRealScriptSpeed()));
-	connect(getGuiActions("actionIncrease_Time_Speed"), SIGNAL(triggered()), nav, SLOT(increaseTimeSpeed()));
-	connect(getGuiActions("actionDecrease_Time_Speed"), SIGNAL(triggered()), nav, SLOT(decreaseTimeSpeed()));
-	connect(getGuiActions("actionIncrease_Time_Speed_Less"), SIGNAL(triggered()), nav, SLOT(increaseTimeSpeedLess()));
-	connect(getGuiActions("actionDecrease_Time_Speed_Less"), SIGNAL(triggered()), nav, SLOT(decreaseTimeSpeedLess()));
-	connect(getGuiActions("actionSet_Real_Time_Speed"), SIGNAL(triggered()), nav, SLOT(toggleRealTimeSpeed()));
-	connect(getGuiActions("actionSet_Time_Rate_Zero"), SIGNAL(triggered()), nav, SLOT(setZeroTimeSpeed()));
-	connect(getGuiActions("actionReturn_To_Current_Time"), SIGNAL(triggered()), nav, SLOT(setTimeNow()));
+	connect(getGuiActions("actionIncrease_Time_Speed"), SIGNAL(triggered()), core, SLOT(increaseTimeSpeed()));
+	connect(getGuiActions("actionDecrease_Time_Speed"), SIGNAL(triggered()), core, SLOT(decreaseTimeSpeed()));
+	connect(getGuiActions("actionIncrease_Time_Speed_Less"), SIGNAL(triggered()), core, SLOT(increaseTimeSpeedLess()));
+	connect(getGuiActions("actionDecrease_Time_Speed_Less"), SIGNAL(triggered()), core, SLOT(decreaseTimeSpeedLess()));
+	connect(getGuiActions("actionSet_Real_Time_Speed"), SIGNAL(triggered()), core, SLOT(toggleRealTimeSpeed()));
+	connect(getGuiActions("actionSet_Time_Rate_Zero"), SIGNAL(triggered()), core, SLOT(setZeroTimeSpeed()));
+	connect(getGuiActions("actionReturn_To_Current_Time"), SIGNAL(triggered()), core, SLOT(setTimeNow()));
 	connect(getGuiActions("actionSwitch_Equatorial_Mount"), SIGNAL(toggled(bool)), mmgr, SLOT(setEquatorialMount(bool)));
 	getGuiActions("actionSwitch_Equatorial_Mount")->setChecked(mmgr->getMountMode() != StelMovementMgr::MountAltAzimuthal);
-	connect(getGuiActions("actionAdd_Solar_Hour"), SIGNAL(triggered()), nav, SLOT(addHour()));
-	connect(getGuiActions("actionAdd_Solar_Day"), SIGNAL(triggered()), nav, SLOT(addDay()));
-	connect(getGuiActions("actionAdd_Solar_Week"), SIGNAL(triggered()), nav, SLOT(addWeek()));
-	connect(getGuiActions("actionSubtract_Solar_Hour"), SIGNAL(triggered()), nav, SLOT(subtractHour()));
-	connect(getGuiActions("actionSubtract_Solar_Day"), SIGNAL(triggered()), nav, SLOT(subtractDay()));
-	connect(getGuiActions("actionSubtract_Solar_Week"), SIGNAL(triggered()), nav, SLOT(subtractWeek()));
-	connect(getGuiActions("actionAdd_Sidereal_Day"), SIGNAL(triggered()), nav, SLOT(addSiderealDay()));
-	connect(getGuiActions("actionAdd_Sidereal_Week"), SIGNAL(triggered()), nav, SLOT(addSiderealWeek()));
-	connect(getGuiActions("actionSubtract_Sidereal_Day"), SIGNAL(triggered()), nav, SLOT(subtractSiderealDay()));
-	connect(getGuiActions("actionSubtract_Sidereal_Week"), SIGNAL(triggered()), nav, SLOT(subtractSiderealWeek()));
-	connect(getGuiActions("actionSet_Home_Planet_To_Selected"), SIGNAL(triggered()), nav, SLOT(moveObserverToSelected()));
+	connect(getGuiActions("actionAdd_Solar_Hour"), SIGNAL(triggered()), core, SLOT(addHour()));
+	connect(getGuiActions("actionAdd_Solar_Day"), SIGNAL(triggered()), core, SLOT(addDay()));
+	connect(getGuiActions("actionAdd_Solar_Week"), SIGNAL(triggered()), core, SLOT(addWeek()));
+	connect(getGuiActions("actionSubtract_Solar_Hour"), SIGNAL(triggered()), core, SLOT(subtractHour()));
+	connect(getGuiActions("actionSubtract_Solar_Day"), SIGNAL(triggered()), core, SLOT(subtractDay()));
+	connect(getGuiActions("actionSubtract_Solar_Week"), SIGNAL(triggered()), core, SLOT(subtractWeek()));
+	connect(getGuiActions("actionAdd_Sidereal_Day"), SIGNAL(triggered()), core, SLOT(addSiderealDay()));
+	connect(getGuiActions("actionAdd_Sidereal_Week"), SIGNAL(triggered()), core, SLOT(addSiderealWeek()));
+	connect(getGuiActions("actionSubtract_Sidereal_Day"), SIGNAL(triggered()), core, SLOT(subtractSiderealDay()));
+	connect(getGuiActions("actionSubtract_Sidereal_Week"), SIGNAL(triggered()), core, SLOT(subtractSiderealWeek()));
+	connect(getGuiActions("actionSet_Home_Planet_To_Selected"), SIGNAL(triggered()), core, SLOT(moveObserverToSelected()));
 
 	// connect the actor after setting the nightmode.
 	// StelApp::init() already set flagNightMode for us, don't do it twice!
@@ -482,7 +486,10 @@ void StelGui::init(QGraphicsWidget* atopLevelGraphicsWidget, StelAppGraphicsWidg
 
 	skyGui->setGeometry(stelAppGraphicsWidget->geometry());
 	skyGui->updateBarsPos();
-
+	
+	StelApp *app = &StelApp::getInstance();
+	connect(app, SIGNAL(languageChanged()), this, SLOT(updateI18n()));
+	connect(app, SIGNAL(colorSchemeChanged(const QString&)), this, SLOT(setStelStyle(const QString&)));
 	initDone = true;
 }
 
@@ -531,7 +538,6 @@ void StelGui::setStelStyle(const QString& section)
 	}
 	qApp->setStyleSheet(currentStelStyle.qtStyleSheet);
 
-	skyGui->setStelStyle(currentStelStyle);
 	locationDialog.styleChanged();
 	dateTimeDialog.styleChanged();
 	configurationDialog->styleChanged();
@@ -546,20 +552,12 @@ void StelGui::setStelStyle(const QString& section)
 void StelGui::updateI18n()
 {
 	StelGuiBase::updateI18n();
-
-	// Update the dialogs
-	configurationDialog->languageChanged();
-	dateTimeDialog.languageChanged();
-	helpDialog.languageChanged();
-	locationDialog.languageChanged();
-	searchDialog.languageChanged();
-	viewDialog.languageChanged();
 }
 
 void StelGui::update()
 {
-	StelNavigator* nav = StelApp::getInstance().getCore()->getNavigator();
-	if (nav->getTimeRate()<-0.99*JD_SECOND)
+	StelCore* core = StelApp::getInstance().getCore();
+	if (core->getTimeRate()<-0.99*StelCore::JD_SECOND)
 	{
 		if (buttonTimeRewind->isChecked()==false)
 			buttonTimeRewind->setChecked(true);
@@ -569,7 +567,7 @@ void StelGui::update()
 		if (buttonTimeRewind->isChecked()==true)
 			buttonTimeRewind->setChecked(false);
 	}
-	if (nav->getTimeRate()>1.01*JD_SECOND)
+	if (core->getTimeRate()>1.01*StelCore::JD_SECOND)
 	{
 		if (buttonTimeForward->isChecked()==false)
 			buttonTimeForward->setChecked(true);
@@ -579,16 +577,16 @@ void StelGui::update()
 		if (buttonTimeForward->isChecked()==true)
 			buttonTimeForward->setChecked(false);
 	}
-	if (nav->getTimeRate() == 0) {
+	if (core->getTimeRate() == 0) {
 		if (buttonTimeRealTimeSpeed->isChecked() != StelButton::ButtonStateNoChange)
 			buttonTimeRealTimeSpeed->setChecked(StelButton::ButtonStateNoChange);
-	} else if (nav->getRealTimeSpeed()) {
+	} else if (core->getRealTimeSpeed()) {
 		if (buttonTimeRealTimeSpeed->isChecked() != StelButton::ButtonStateOn)
 			buttonTimeRealTimeSpeed->setChecked(StelButton::ButtonStateOn);
 	} else if (buttonTimeRealTimeSpeed->isChecked() != StelButton::ButtonStateOff) {
 		buttonTimeRealTimeSpeed->setChecked(StelButton::ButtonStateOff);
 	}
-	const bool isTimeNow=nav->getIsTimeNow();
+	const bool isTimeNow=core->getIsTimeNow();
 	if (buttonTimeCurrent->isChecked()!=isTimeNow)
 		buttonTimeCurrent->setChecked(isTimeNow);
 	StelMovementMgr* mmgr = GETSTELMODULE(StelMovementMgr);
@@ -683,7 +681,7 @@ void StelGui::update()
 	}
 
 	if (dateTimeDialog.visible())
-		dateTimeDialog.setDateTime(nav->getJDay());
+		dateTimeDialog.setDateTime(core->getJDay());
 }
 
 // Add a new progress bar in the lower right corner of the screen.
