@@ -20,7 +20,7 @@
 #include "StelApp.hpp"
 #include "StelCore.hpp"
 #include "StelProjector.hpp"
-#include "StelNavigator.hpp"
+
 #include "StelGuiItems.hpp"
 #include "StelLocaleMgr.hpp"
 #include "StelLocation.hpp"
@@ -330,17 +330,10 @@ BottomStelBar::BottomStelBar(QGraphicsItem* parent, const QPixmap& pixLeft, cons
 	QColor color = QColor::fromRgbF(1,1,1,1);
 	setColor(color);
 
-#ifdef BUILD_FOR_MAEMO
-	QFont font("SmallSystemFont");
-
-#else
-	QFont font = QApplication::font();
-	font.setPixelSize(12)
-#endif
-	datetime->setFont(font);
-	location->setFont(font);
-	fov->setFont(font);
-	fps->setFont(font);
+	datetime->font().setPixelSize(12);
+	location->font().setPixelSize(12);
+	fov->font().setPixelSize(12);
+	fps->font().setPixelSize(12);
 
 	flagShowTime = true;
 	flagShowLocation = true;
@@ -532,7 +525,7 @@ void BottomStelBar::updateButtonsGroups()
 void BottomStelBar::updateText(bool updatePos)
 {
 	StelCore* core = StelApp::getInstance().getCore();
-	double jd = core->getNavigator()->getJDay();
+	double jd = core->getJDay();
 
 	QString newDate = flagShowTime ? StelApp::getInstance().getLocaleMgr().getPrintableDateLocal(jd) +"   "
 			+StelApp::getInstance().getLocaleMgr().getPrintableTimeLocal(jd) : " ";
@@ -542,10 +535,10 @@ void BottomStelBar::updateText(bool updatePos)
 		datetime->setText(newDate);
 	}
 
-	QString newLocation = flagShowLocation ? q_(core->getNavigator()->getCurrentLocation().planetName) +", "
-			+core->getNavigator()->getCurrentLocation().name + ", "
+	QString newLocation = flagShowLocation ? q_(core->getCurrentLocation().planetName) +", "
+			+core->getCurrentLocation().name + ", "
 			// xgettext:no-c-format
-			+q_("%1m").arg(core->getNavigator()->getCurrentLocation().altitude) : " ";
+			+q_("%1m").arg(core->getCurrentLocation().altitude) : " ";
 	if (location->text()!=newLocation)
 	{
 		updatePos = true;
@@ -575,8 +568,8 @@ void BottomStelBar::updateText(bool updatePos)
 		QRectF rectCh = getButtonsBoundingRect();
 		location->setPos(0, 0);
 		datetime->setPos(rectCh.right()-datetime->boundingRect().width()-5,0);
-		fov->setPos(datetime->x()-230, 0);
-		fps->setPos(datetime->x()-140, 0);
+		fov->setPos(datetime->x()-200, 0);
+		fps->setPos(datetime->x()-95, 0);
 	}
 }
 
