@@ -21,6 +21,7 @@
 #include "ViewDialog.hpp"
 #include "ui_viewDialog.h"
 #include "AddRemoveLandscapesDialog.hpp"
+#include "AtmosphereDialog.hpp"
 #include "StelApp.hpp"
 #include "StelCore.hpp"
 #include "StelSkyCultureMgr.hpp"
@@ -52,6 +53,7 @@ ViewDialog::ViewDialog()
 {
 	ui = new Ui_viewDialogForm;
 	addRemoveLandscapesDialog = NULL;
+        atmosphereDialog=NULL;
 }
 
 ViewDialog::~ViewDialog()
@@ -60,6 +62,8 @@ ViewDialog::~ViewDialog()
 	ui=NULL;
 	delete addRemoveLandscapesDialog;
 	addRemoveLandscapesDialog = NULL;
+        delete atmosphereDialog;
+        atmosphereDialog = NULL;
 }
 
 void ViewDialog::languageChanged()
@@ -83,6 +87,7 @@ void ViewDialog::styleChanged()
 void ViewDialog::createDialogContent()
 {
 	ui->setupUi(dialog);
+	connect(&StelApp::getInstance(), SIGNAL(languageChanged()), this, SLOT(languageChanged()));
 
 	// Set the Sky tab activated by default
 	ui->stackedWidget->setCurrentIndex(0);
@@ -195,6 +200,18 @@ void ViewDialog::createDialogContent()
 	ui->lightPollutionSpinBox->setValue(StelApp::getInstance().getCore()->getSkyDrawer()->getBortleScale());
 	connect(ui->lightPollutionSpinBox, SIGNAL(valueChanged(int)), lmgr, SLOT(setAtmosphereBortleLightPollution(int)));
 	connect(ui->lightPollutionSpinBox, SIGNAL(valueChanged(int)), StelApp::getInstance().getCore()->getSkyDrawer(), SLOT(setBortleScale(int)));
+	
+	// GZ: changes for refraction
+        //ui->pressureDoubleSpinBox->setValue(StelApp::getInstance().getCore()->getSkyDrawer()->getAtmospherePressure());
+        //connect(ui->pressureDoubleSpinBox, SIGNAL(valueChanged(double)), StelApp::getInstance().getCore()->getSkyDrawer(), SLOT(setAtmospherePressure(double)));
+        //ui->temperatureDoubleSpinBox->setValue(StelApp::getInstance().getCore()->getSkyDrawer()->getAtmosphereTemperature());
+        //connect(ui->temperatureDoubleSpinBox, SIGNAL(valueChanged(double)), StelApp::getInstance().getCore()->getSkyDrawer(), SLOT(setAtmosphereTemperature(double)));
+        //ui->extinctionDoubleSpinBox->setValue(StelApp::getInstance().getCore()->getSkyDrawer()->getExtinctionCoefficient());
+        //connect(ui->extinctionDoubleSpinBox, SIGNAL(valueChanged(double)), StelApp::getInstance().getCore()->getSkyDrawer(), SLOT(setExtinctionCoefficient(double)));
+        //// instead
+        connect(ui->pushButtonAtmosphereDetails, SIGNAL(clicked()), this, SLOT(showAtmosphereDialog()));
+        // GZ: Done
+
 
 	ui->useAsDefaultLandscapeCheckBox->setChecked(lmgr->getCurrentLandscapeID()==lmgr->getDefaultLandscapeID());
 	ui->useAsDefaultLandscapeCheckBox->setEnabled(lmgr->getCurrentLandscapeID()!=lmgr->getDefaultLandscapeID());
@@ -220,6 +237,11 @@ void ViewDialog::createDialogContent()
 	connect(a, SIGNAL(toggled(bool)), ui->showMeridianLineCheckBox, SLOT(setChecked(bool)));
 	connect(ui->showMeridianLineCheckBox, SIGNAL(toggled(bool)), a, SLOT(setChecked(bool)));
 
+	ui->showHorizonLineCheckBox->setChecked(glmgr->getFlagHorizonLine());
+	a = gui->getGuiActions("actionShow_Horizon_Line");
+	connect(a, SIGNAL(toggled(bool)), ui->showHorizonLineCheckBox, SLOT(setChecked(bool)));
+	connect(ui->showHorizonLineCheckBox, SIGNAL(toggled(bool)), a, SLOT(setChecked(bool)));
+
 	ui->showEquatorialGridCheckBox->setChecked(glmgr->getFlagEquatorGrid());
 	a = gui->getGuiActions("actionShow_Equatorial_Grid");
 	connect(a, SIGNAL(toggled(bool)), ui->showEquatorialGridCheckBox, SLOT(setChecked(bool)));
@@ -427,6 +449,10 @@ void ViewDialog::landscapeChanged(QListWidgetItem* item)
 	ui->landscapeTextBrowser->setHtml(lmgr->getCurrentLandscapeHtmlDescription());
 	ui->useAsDefaultLandscapeCheckBox->setChecked(lmgr->getDefaultLandscapeID()==lmgr->getCurrentLandscapeID());
 	ui->useAsDefaultLandscapeCheckBox->setEnabled(lmgr->getDefaultLandscapeID()!=lmgr->getCurrentLandscapeID());
+	//StelSkyDrawer *drawer=StelApp::getInstance().getSkyDrawer();
+	// GZ: Reset values that might have changed.
+	ui->showFogCheckBox->setChecked(lmgr->getFlagFog());
+	ui->lightPollutionSpinBox->setValue(StelApp::getInstance().getCore()->getSkyDrawer()->getBortleScale());
 }
 
 void ViewDialog::showAddRemoveLandscapesDialog()
@@ -437,6 +463,18 @@ void ViewDialog::showAddRemoveLandscapesDialog()
 	addRemoveLandscapesDialog->setVisible(true);
 }
 
+void ViewDialog::showAtmosphereDialog()
+{
+        if(atmosphereDialog == NULL)
+                atmosphereDialog = new AtmosphereDialog();
+        //ui->temperatureDoubleSpinBox->setValue(StelApp::getInstance().getCore()->getSkyDrawer()->getAtmosphereTemperature());
+        //ui->extinctionDoubleSpinBox->setValue(StelApp::getInstance().getCore()->getSkyDrawer()->getExtinctionCoefficient());
+        //ui->pressureDoubleSpinBox->setValue(StelApp::getInstance().getCore()->getSkyDrawer()->getAtmospherePressure());
+
+        atmosphereDialog->setVisible(true);
+}
+
+
 void ViewDialog::shootingStarsZHRChanged()
 {
 	MeteorMgr* mmgr = GETSTELMODULE(MeteorMgr);
